src/hotspot/share/gc/parallel/psCardTable.cpp
changeset 49488 1f9dd2360b17
parent 49194 ece10494786c
parent 49455 848864ed9b17
child 49679 7084eec5c723
--- a/src/hotspot/share/gc/parallel/psCardTable.cpp	Thu Mar 29 20:12:02 2018 +0100
+++ b/src/hotspot/share/gc/parallel/psCardTable.cpp	Sat Mar 24 01:08:35 2018 +0100
@@ -392,10 +392,10 @@
 
 // Assumes that only the base or the end changes.  This allows indentification
 // of the region that is being resized.  The
 // CardTableModRefBS::resize_covered_region() is used for the normal case
 // where the covered regions are growing or shrinking at the high end.
 // The method resize_covered_region_by_end() is analogous to
-// CardTableModRefBS::resize_covered_region() but
+// CardTable::resize_covered_region() but
 // for regions that grow or shrink at the low end.
 void PSCardTable::resize_covered_region(MemRegion new_region) {
   for (int i = 0; i < _cur_covered_regions; i++) {
@@ -463,7 +463,7 @@
   resize_update_covered_table(changed_region, new_region);
 
   int ind = changed_region;
-  log_trace(gc, barrier)("CardTableModRefBS::resize_covered_region: ");
+  log_trace(gc, barrier)("CardTable::resize_covered_region: ");
   log_trace(gc, barrier)("    _covered[%d].start(): " INTPTR_FORMAT "  _covered[%d].last(): " INTPTR_FORMAT,
                 ind, p2i(_covered[ind].start()), ind, p2i(_covered[ind].last()));
   log_trace(gc, barrier)("    _committed[%d].start(): " INTPTR_FORMAT "  _committed[%d].last(): " INTPTR_FORMAT,
@@ -392,10 +392,10 @@
 // Assumes that only the base or the end changes.  This allows indentification
 // of the region that is being resized.  The
-// CardTableModRefBS::resize_covered_region() is used for the normal case
+// CardTable::resize_covered_region() is used for the normal case
 // where the covered regions are growing or shrinking at the high end.
 // The method resize_covered_region_by_end() is analogous to